#!/bin/bash

# Written by George Smart, M1GEO (http://www.george-smart.co.uk)
#   Some bits by Paul Colby (http://colby.id.au)
# Redistributed under the 'No Rights Reserved' Licence :)

cpu_fsd=226
ram_fsd=222

PREV_TOTAL=0
PREV_IDLE=0

while true; do
  CPU=(`cat /proc/stat | grep '^cpu '`) # Get the total CPU statistics.
  unset CPU[0]                          # Discard the "cpu" prefix.
  IDLE=${CPU[4]}                        # Get the idle CPU time.

  # Calculate the total CPU time.
  TOTAL=0
  for VALUE in "${CPU[@]}"; do
    let "TOTAL=$TOTAL+$VALUE"
  done

  # Calculate the CPU usage since we last checked.
  let "DIFF_IDLE=$IDLE-$PREV_IDLE"
  let "DIFF_TOTAL=$TOTAL-$PREV_TOTAL"
  let "DIFF_USAGE=(1000*($DIFF_TOTAL-$DIFF_IDLE)/$DIFF_TOTAL+5)/10"

  ram=`free -m | grep "Mem:" | awk '{print ((($3-$6-$7)/$2))*100+0.5}' | sed -e 's/\..*//'`
  ram_h=$((($ram*$ram_fsd)/100))

  cpu=$DIFF_USAGE
  cpu_h=$((($cpu*$cpu_fsd)/100))

  echo -ne "\rCPU: ${cpu}% ($cpu_h)	RAM: ${ram}% ($ram_h)                   "

  sudo k8055 -a1:$cpu_h -a2:$ram_h 2>&1 > /dev/null

  # Remember the total and idle CPU times for the next check.
  PREV_TOTAL="$TOTAL"
  PREV_IDLE="$IDLE"

  # Wait before checking again.
done
